# Changelog

## v0.2.1 – 2025-05-09

### Improved

- Little README touch up
- About 50% test coverage

## v0.2.0 – 2025-05-09

### Added

- Display record's TTL values from DNS in output table

### Fixed

- TXT record validation and concatenation for escaped quotes

### Improved

- Resolve authoritative NS only once per zone - reduces wall time for "check" to < 50%

## v0.1.0 – 2025-05-08

- Initial release
